==> matrix_synapse_testutils-1.84.0.0.tar.gz: matrix_synapse_testutils-1.84.0.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

### [1.84.0.0] - 2023-11-18

### Updated

- Synapse to 1.83.0

### [1.83.0.0] - 2023-11-18

### Updated

- Synapse to 1.83.0

### [1.82.0.0] - 2023-11-18

### Updated

- Synapse to 1.82.0

### [1.81.0.0] - 2023-11-18

### Updated

- Synapse to 1.81.0

### [1.80.0.0] - 2023-04-03

### Updated

- Synapse to 1.80.0

### [1.79.0.0] - 2023-03-15

### Updated

- Synapse to 1.79.0


### [1.78.0.0] - 2023-02-28

### Updated

- Synapse to 1.78.0

### [1.77.0.0] - 2023-02-14

### Updated

- Synapse to 1.77.0

### [1.76.0.0] - 2023-02-02

### Updated

- Synapse to 1.76.0

### [1.75.0.0] - 2023-01-18

### Fixed

- Readme fixed spath to update script

### Updated

- Synapse to 1.75.0

### [1.74.0.0] - 2022-12-21

### Updated

- Synapse to 1.74.0

## [1.73.0.1] - 2022-12-21

### Fix

- Fixes wrong synapse dependency

### [1.73.0.0] - 2022-12-07

### Updated

- Synapse to 1.73.0

## [1.72.0.1] - 2022-12-21

### Updated

- Fixes wrong synapse dependency

### [1.72.0.0] - 2022-11-22

### Updated

- Synapse to 1.72.0

### [1.71.0.0] - 2022-11-09

### Updated

- Synapse to 1.71.0

### [1.70.1.0] - 2022-11-09

### Updated

- Synapse to 1.70.1

### [1.70.0.0] - 2022-11-09

### Updated

- Synapse to 1.70.0

### [1.69.0.0] - 2022-11-09

### Updated

- Synapse to 1.69.0

### [1.68.0.0] - 2022-11-09

### Updated

- Synapse to 1.68.0

### [1.67.0.0] - 2022-11-09

### Updated

- Synapse to 1.67.0

### [1.66.0.0] - 2022-11-09

### Updated

- Synapse to 1.66.0

### [1.65.0.0] - 2022-11-09

### Updated

- Synapse to 1.65.0

### Fixed

- Location of github action workflow file `build.yml`
- Fix robustness for matrix-synapse name and packages changes and rebuilding in the same path (updater script)

[unreleased]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.84.0.0...HEAD
[1.84.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.83.0.0...v1.84.0.0
[1.83.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.82.0.0...v1.83.0.0
[1.82.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.81.0.0...v1.82.0.0
[1.81.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.80.0.0...v1.81.0.0
[1.80.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.79.0.0...v1.80.0.0
[1.79.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.78.0.0...v1.79.0.0
[1.78.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.77.0.0...v1.78.0.0
[1.77.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.76.0.0...v1.77.0.0
[1.76.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.75.0.0...v1.76.0.0
[1.75.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.74.0.0...v1.75.0.0
[1.74.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.73.0.1...v1.74.0.0
[1.73.0.1]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.73.0.0...v1.73.0.1
[1.73.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.72.0.1...v1.73.0.0
[1.72.0.1]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.72.0.0...v1.72.0.1
[1.72.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.71.0.0...v1.72.0.0
[1.71.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.70.1.0...v1.71.0.0
[1.70.1.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.70.0.0...v1.70.1.0
[1.70.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.69.0.0...v1.70.0.0
[1.69.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.68.0.0...v1.69.0.0
[1.68.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.67.0.0...v1.68.0.0
[1.67.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.66.0.0...v1.67.0.0
[1.66.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.65.0.0...v1.66.0.0
[1.65.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.65.0.0

==> matrix_synapse_testutils-1.85.0.0.tar.gz: matrix_synapse_testutils-1.85.0.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

### [1.85.0.0] - 2023-11-18

### Updated

- Synapse to 1.85.0

### [1.84.1.0] - 2023-11-18

### Updated

- Synapse to 1.84.1

### [1.84.0.0] - 2023-11-18

### Updated

- Synapse to 1.84.0

### [1.83.0.0] - 2023-11-18

### Updated

- Synapse to 1.83.0

### [1.82.0.0] - 2023-11-18

### Updated

- Synapse to 1.82.0

### [1.81.0.0] - 2023-11-18

### Updated

- Synapse to 1.81.0

### [1.80.0.0] - 2023-04-03

### Updated

- Synapse to 1.80.0

### [1.79.0.0] - 2023-03-15

### Updated

- Synapse to 1.79.0


### [1.78.0.0] - 2023-02-28

### Updated

- Synapse to 1.78.0

### [1.77.0.0] - 2023-02-14

### Updated

- Synapse to 1.77.0

### [1.76.0.0] - 2023-02-02

### Updated

- Synapse to 1.76.0

### [1.75.0.0] - 2023-01-18

### Fixed

- Readme fixed spath to update script

### Updated

- Synapse to 1.75.0

### [1.74.0.0] - 2022-12-21

### Updated

- Synapse to 1.74.0

## [1.73.0.1] - 2022-12-21

### Fix

- Fixes wrong synapse dependency

### [1.73.0.0] - 2022-12-07

### Updated

- Synapse to 1.73.0

## [1.72.0.1] - 2022-12-21

### Updated

- Fixes wrong synapse dependency

### [1.72.0.0] - 2022-11-22

### Updated

- Synapse to 1.72.0

### [1.71.0.0] - 2022-11-09

### Updated

- Synapse to 1.71.0

### [1.70.1.0] - 2022-11-09

### Updated

- Synapse to 1.70.1

### [1.70.0.0] - 2022-11-09

### Updated

- Synapse to 1.70.0

### [1.69.0.0] - 2022-11-09

### Updated

- Synapse to 1.69.0

### [1.68.0.0] - 2022-11-09

### Updated

- Synapse to 1.68.0

### [1.67.0.0] - 2022-11-09

### Updated

- Synapse to 1.67.0

### [1.66.0.0] - 2022-11-09

### Updated

- Synapse to 1.66.0

### [1.65.0.0] - 2022-11-09

### Updated

- Synapse to 1.65.0

### Fixed

- Location of github action workflow file `build.yml`
- Fix robustness for matrix-synapse name and packages changes and rebuilding in the same path (updater script)

[unreleased]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.85.0.0...HEAD
[1.85.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.84.1.0...v1.85.0.0
[1.84.1.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.84.0.0...v1.84.1.0
[1.84.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.83.0.0...v1.84.0.0
[1.83.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.82.0.0...v1.83.0.0
[1.82.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.81.0.0...v1.82.0.0
[1.81.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.80.0.0...v1.81.0.0
[1.80.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.79.0.0...v1.80.0.0
[1.79.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.78.0.0...v1.79.0.0
[1.78.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.77.0.0...v1.78.0.0
[1.77.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.76.0.0...v1.77.0.0
[1.76.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.75.0.0...v1.76.0.0
[1.75.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.74.0.0...v1.75.0.0
[1.74.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.73.0.1...v1.74.0.0
[1.73.0.1]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.73.0.0...v1.73.0.1
[1.73.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.72.0.1...v1.73.0.0
[1.72.0.1]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.72.0.0...v1.72.0.1
[1.72.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.71.0.0...v1.72.0.0
[1.71.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.70.1.0...v1.71.0.0
[1.70.1.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.70.0.0...v1.70.1.0
[1.70.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.69.0.0...v1.70.0.0
[1.69.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.68.0.0...v1.69.0.0
[1.68.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.67.0.0...v1.68.0.0
[1.67.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.66.0.0...v1.67.0.0
[1.66.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.65.0.0...v1.66.0.0
[1.65.0.0]: https://github.com/conhealth/LifeTime-Desktop/compare/v1.65.0.0
